@@ -185,20 +185,49 @@ public interface UserManager {
 	 * @throws UserRetrievalFault
 	 */
 	void setUserProfessionalBackground(long userId, String summary) throws UserManagementSystemException, UserRetrievalFault;
-	
+
 	/**
 	 * 
 	 * @return a list of all portal active users (using indexed version search) no matter if the belong or not to a VRE, if a user is deactived is not returned
 	 * @throws UserManagementSystemException
 	 */
 	List<GCubeUser> listUsers() throws UserManagementSystemException;
-	
+	/**
+	 * 
+	 * Returns a range of all the users.
+	 *
+	 * Useful when paginating results. 
+	 * Returns a maximum of end - start instances, 0 refers to the first result in the set. 
+	 * 
+	 * @param start start the lower bound of the range of users
+	 * @param end end the upper bound of the range of users (not inclusive)
+	 * @return the range of users
+	 * @throws UserManagementSystemException
+	 */
+	List<GCubeUser> listUsers(int start, int end) throws UserManagementSystemException;
+	/**
+	 * Returns the number of total users.
+	 *
+	 * @return the number of users
+	 * @throws UserManagementSystemException 
+	 */
+	int getUsersCount() throws UserManagementSystemException;
 	/**
 	 * @param indexed set to true to use the indexed version search false for a real time query to the DB.
 	 * @return a list of all portal active users no matter if the belong or not to a VRE, if a user is deactived is not returned
 	 * @throws UserManagementSystemException
 	 */
 	List<GCubeUser> listUsers(boolean indexed) throws UserManagementSystemException;
+	/**
+	 * 
+	 * @param keywords the keywords (space separated), which may occur in the user's first name, middle name, last name, username, or email address
+	 * @param groupId
+	 * @return all the users who match the keywords ordered by username (Ascendent order)
+	 * @throws UserManagementSystemException
+	 * @throws GroupRetrievalFault
+	 * @throws UserRetrievalFault
+	 */
+	List<GCubeUser> searchUsersByGroup(String keywords, long groupId) throws GroupRetrievalFault;
 	/**
 	 * 
 	 * @param groupId the LR groupId
@@ -208,6 +237,22 @@ public interface UserManager {
 	 * @throws UserRetrievalFault
 	 */
 	List<GCubeUser> listUsersByGroup(long groupId) throws UserManagementSystemException, GroupRetrievalFault, UserRetrievalFault;
+	/**
+	 * 
+	 * @param groupId the LR groupId
+	 * @return
+	 * @throws UserManagementSystemException
+	 * @throws GroupRetrievalFault
+	 * @throws UserRetrievalFault
+	 */
+	List<GCubeUser> listUsersByGroup(long groupId, int start, int end) throws UserManagementSystemException, GroupRetrievalFault, UserRetrievalFault;
+	/**
+	 * Returns the number of users in the group (VRE).
+	 *
+	 * @return the number of users in the group (VRE).
+	 * @throws GroupRetrievalFault 
+	 */
+	int getGroupUsersCount(long groupId) throws GroupRetrievalFault;
 	/**
 	 * Retrieve a list of users having a global role (e.g., Administrator)
 	 * @param roleId
@@ -414,7 +459,7 @@ public interface UserManager {
 	 * @return true if ok
 	 */
 	boolean updateJobTitle(long userId, String theJob);
-	
+
 	/**
 	 * 
 	 * @param attributeKey the name of the attribute you want to read its value
@@ -431,7 +476,7 @@ public interface UserManager {
 	 * @throws UserRetrievalFault
 	 */
 	void saveCustomAttr(long userId, String attributeKey, Serializable value) throws UserRetrievalFault;
-	
+
 	/**
 	 * Retrieve the list of user identifiers by group id.
 	 * @return
